@@ -53,11 +53,11 @@ mf_prop_typo <- function(x, var,
                          inches = 0.3,
                          val_max,
                          symbol = "circle",
-                         pal = "Dynamic",
-                         alpha = 1,
+                         pal,
+                         alpha = NULL,
                          rev = FALSE,
                          val_order,
-                         border = getOption("mapsf.fg"),
+                         border,
                          lwd = .7,
                          lwd_max = 15,
                          col_na = "white",
@@ -68,19 +68,30 @@ mf_prop_typo <- function(x, var,
                          leg_val_rnd = c(0),
                          leg_no_data = "No data",
                          leg_frame = c(FALSE, FALSE),
-                         leg_frame_border = getOption("mapsf.fg"),
+                         leg_frame_border,
                          leg_horiz = FALSE,
                          leg_adj = c(0, 0),
-                         leg_fg = getOption("mapsf.fg"),
-                         leg_bg = getOption("mapsf.bg"),
+                         leg_fg,
+                         leg_bg,
                          leg_size = 1,
-                         leg_box_border = getOption("mapsf.fg"),
+                         leg_box_border,
                          leg_box_cex = c(1, 1),
                          add = TRUE) {
   # default
   op <- par(mar = getOption("mapsf.mar"), no.readonly = TRUE)
   on.exit(par(op))
 
+  pal <- go(pal, "pal_quali", "Dynamic")
+  leg_box_border <- go(leg_box_border, "highlight")
+  leg_fg <- go(leg_fg, "highlight")
+  leg_bg <- go(leg_bg, "foreground", getOption("mapsf.background"))
+  leg_frame_border <- go(
+    leg_frame_border, "foreground",
+    getOption("mapsf.highlight")
+  )
+  border <- go(border, "background")
+
+
   var2 <- var[2]
   var1 <- var[1]
 
@@ -128,7 +139,7 @@ mf_prop_typo <- function(x, var,
     val <- seq(min(xl[[var1]]), max(xl[[var1]]), length.out = 4)
     leg_pos <- split_leg(leg_pos)
 
-
+    ccol <- getOption("mapsf.highlight")
 
     if (length(leg_pos) == 1) {
       la1 <- list(
@@ -136,7 +147,7 @@ mf_prop_typo <- function(x, var,
         val = val,
         title = leg_title[1],
         lwd = max(xl$lwd),
-        col = "grey20",
+        col = ccol,
         val_rnd = leg_val_rnd[1]
       )
       lg <- do.call(leg_comp, la1)
@@ -149,8 +160,8 @@ mf_prop_typo <- function(x, var,
         no_data = no_data,
         no_data_txt = leg_no_data,
         pal = pal,
-        box_cex = leg_box_cex,
-        box_border = leg_box_border
+        box_cex = leg_box_cex * c(1, .5),
+        box_border = pal
       )
       lg <- do.call(leg_comp, la2)
       leg_draw(lg,
@@ -163,7 +174,7 @@ mf_prop_typo <- function(x, var,
       leg(
         type = "prop_line",
         pos = leg_pos[[1]], val = val, lwd = max(xl$lwd),
-        col = "grey20",
+        col = ccol,
         title = leg_title[1], title_cex = leg_title_cex[1],
         val_cex = leg_val_cex[1], val_rnd = leg_val_rnd,
         frame = leg_frame[1], bg = leg_bg, fg = leg_fg
@@ -174,7 +185,7 @@ mf_prop_typo <- function(x, var,
         title_cex = leg_title_cex[2], val_cex = leg_val_cex[2],
         col_na = col_na, no_data = no_data, no_data_txt = leg_no_data,
         frame = leg_frame[2], pal = pal, bg = leg_bg, fg = leg_fg,
-        box_cex = leg_box_cex, box_border = leg_box_border
+        box_cex = leg_box_cex * c(1, .5), box_border = pal
       )
     }
     par(op2)
@@ -244,7 +255,16 @@ mf_prop_typo <- function(x, var,
     inches = inches
   )
 
-  leg_pos <- split_leg(leg_pos)
+  border <- getOption("mapsf.highlight")
+  if (is.null(getOption("mapsf.legacy"))) {
+    ccol <- getOption("mapsf.foreground")
+  } else {
+    ccol <- "grey80"
+  }
+  if (all(leg_frame, !leg_horiz)) {
+    ccol <- getOption("mapsf.background")
+  }
+
   if (length(leg_pos) == 1) {
     ## TEST Double args
     la1 <- list(
@@ -253,7 +273,7 @@ mf_prop_typo <- function(x, var,
       title = leg_title[1],
       symbol = symbol,
       inches = size_max,
-      col = "grey80",
+      col = ccol,
       val_rnd = leg_val_rnd[1],
       border = border,
       lwd = lwd, horiz = leg_horiz,
@@ -284,14 +304,13 @@ mf_prop_typo <- function(x, var,
     leg(
       type = "prop",
       pos = leg_pos[[1]], val = val, title = leg_title[1],
-      symbol = symbol, inches = size_max, col = "grey80",
+      symbol = symbol, inches = size_max, col = ccol,
       title_cex = leg_title_cex[1], val_cex = leg_val_cex[1],
       val_rnd = leg_val_rnd, horiz = leg_horiz,
       frame = leg_frame[1], border = border,
       lwd = lwd, bg = leg_bg, fg = leg_fg,
       self_adjust = TRUE, mar = getOption("mapsf.mar")
     )
-
     leg(
       type = "typo",
       pos = leg_pos[[2]], val = val_order, title = leg_title[2],
