@@ -12,10 +12,11 @@
 #' mtq <- mf_get_mtq()
 #' mf_shadow(mtq)
 #' mf_map(mtq, add = TRUE)
-mf_shadow <- function(x, col = "grey50", cex = 1, add = FALSE) {
+mf_shadow <- function(x, col, cex = 1, add = FALSE) {
   if (add == FALSE) {
     mf_init(x)
   }
+  col <- go(col, "highlight", "grey50")
   d <- cex * strwidth("M", units = "user", cex = 1) / 3
   z <- st_geometry(x) + c(d, -d)
 
